@@ -1,12 +1,13 @@
-/* filter.c -- LZO packer
+/* filter.c --
 
-   This file is part of the LZO real-time data compression package.
+   This file is part of the lzop file compressor.
 
+   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
 
-   The LZO library and packer is free software; you can redistribute it
-   and/or modify it under the terms of the GNU General Public License as
+   lzop and the LZO library are free software; you can redistribute them
+   and/or modify them under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.
 
@@ -25,7 +26,7 @@
  */
 
 
-#include "lzopack.h"
+#include "lzop.h"
 
 
 /*************************************************************************
@@ -36,7 +37,7 @@ void t_sub1(lzo_byte *p, lzo_uint l)
 {
 	unsigned char b = 0;
 
-	do {
+	if (l > 0) do {
 		*p -= b;
 		b += *p++;
 	} while (--l > 0);
@@ -47,7 +48,7 @@ void t_add1(lzo_byte *p, lzo_uint l)
 {
 	unsigned char b = 0;
 
-	do {
+	if (l > 0) do {
 		b += *p;
 		*p++ = b;
 	} while (--l > 0);
@@ -112,8 +113,10 @@ void t_mtf(lzo_byte *p, lzo_uint l)
 	unsigned char c;
 	int i;
 
-	for (i = 0; i < 256; i++)
-		b[i] = (unsigned char) i;
+	if (l <= 1)
+		return;
+
+	i = 255; do b[i] = (unsigned char) i; while (--i >= 0);
 
 	do {
 		c = *p;
@@ -135,8 +138,10 @@ void t_unmtf(lzo_byte *p, lzo_uint l)
 	unsigned char c;
 	int i;
 
-	for (i = 0; i < 256; i++)
-		b[i] = (unsigned char) i;
+	if (l <= 1)
+		return;
+
+	i = 255; do b[i] = (unsigned char) i; while (--i >= 0);
 
 	do {
 		i = *p;
