@@ -1,12 +1,13 @@
-/* frames.c -- LZO packer
+/* frames.c --
 
-   This file is part of the LZO real-time data compression package.
+   This file is part of the lzop file compressor.
 
+   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
 
-   The LZO library and packer is free software; you can redistribute it
-   and/or modify it under the terms of the GNU General Public License as
+   lzop and the LZO library are free software; you can redistribute them
+   and/or modify them under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.
 
@@ -25,9 +26,9 @@
  */
 
 
-#include "lzopack.h"
+#include "lzop.h"
 
-#if defined(USE_SCREEN)
+#if defined(USE_FRAMES)
 
 #include "screen.h"
 
@@ -128,7 +129,7 @@ static int random_color(void)
 
 	seed = time(NULL);
 #if 0
-	seed = seed * 69069 + 5;
+	seed = seed * 69069L + 5;
 	t = (int)(seed >> 16) % 50;
 #else
 	seed = seed * 0x015a4e35L + 1;
@@ -169,16 +170,12 @@ void screen_show_frames(screen_t *screen)
 		exit(EXIT_ERROR);
 #endif
 
-#if defined(USE_MALLOC)
-	frames = frames_mem = (lzo_byte *) malloc(UNCOMPRESSED_SIZE + sizeof(long));
+	frames = frames_mem = (lzo_byte *) malloc(UNCOMPRESSED_SIZE + 3);
 	if (frames == NULL)
 		return;
-#else
-	frames = wrkmem;
-#endif
 
 	if ((lzo1x_decompress_safe(compressed_frames,COMPRESSED_SIZE,
-	                          frames,&out_len,NULL) != LZO_E_OK)
+	                           frames,&out_len,NULL) != LZO_E_OK)
 	   || (out_len != UNCOMPRESSED_SIZE))
 		exit(EXIT_ERROR);
 #if 0
@@ -232,9 +229,7 @@ void screen_show_frames(screen_t *screen)
 		}
 	}
 
-#if defined(USE_MALLOC)
 	FREE(frames_mem);
-#endif
 
 	for (k = 0; k < lines; k++)
 		screen->clearLine(screen,c_cy+k);
@@ -246,7 +241,7 @@ void screen_show_frames(screen_t *screen)
 }
 
 
-#endif /* USE_SCREEN */
+#endif /* USE_FRAMES */
 
 
 /*
