@@ -1,12 +1,13 @@
-/* s_object.c -- LZO packer
+/* s_object.c --
 
-   This file is part of the LZO real-time data compression package.
+   This file is part of the lzop file compressor.
 
+   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
 
-   The LZO library and packer is free software; you can redistribute it
-   and/or modify it under the terms of the GNU General Public License as
+   lzop and the LZO library are free software; you can redistribute them
+   and/or modify them under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.
 
@@ -25,7 +26,7 @@
  */
 
 
-#include "lzopack.h"
+#include "lzop.h"
 
 #if defined(USE_SCREEN)
 
